==> haskell-resourcet-1.1.7.3-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-resourcet/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resourcet
version: 1.1.7.3
id: resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
key: resou_FD3YBQAG5YCJcmLlgosnnd
license: BSD3
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/resourcet-1.1.7.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/resourcet-1.1.7.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/resourcet-1.1.7.3
hs-libraries: HSresourcet-1.1.7.3-FD3YBQAG5YCJcmLlgosnnd
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    mmorph-1.0.6-1a509ce4d7b5bdf9a92707e79b8069c6
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
haddock-interfaces: /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html: /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resourcet-1.1.7.3-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-resourcet/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resourcet
version: 1.1.7.3
id: resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
key: resou_18RGQAU2akxEhnLKgc9Jq7
license: BSD3
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/resourcet-1.1.7.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/resourcet-1.1.7.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/resourcet-1.1.7.3
hs-libraries: HSresourcet-1.1.7.3-18RGQAU2akxEhnLKgc9Jq7
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
    mmorph-1.0.6-1a509ce4d7b5bdf9a92707e79b8069c6
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
haddock-interfaces: /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html: /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
